pub struct TimeoutAny {
pub timeout_type: TimeoutType,
pub duration: Duration,
}Expand description
Defines a Timeout consisting of a type, duration, and stop class. Timeouts ensure view-changes occur when they are necessary. crate::MinBft outputs timeout requests when a timeout may possibly have to be set. Timeout requests and timeouts must be handled explicitly, see crate::MinBft.
Does not contain a StopClass.
Fields
timeout_type: TimeoutTypeThe type a timeout can have.
duration: DurationThe time until the Timeout is triggered.